__prog__ = 'pytest-rmsis'
__author__ = 'Johannes Fischer'
__email__ = 'johannes.fischer@hebling.de'
__url__ = 'https://github.com/helbling-technik-gmbh/pytest-rmsis'
__copyright__ = 'Copyright Helbling Technik GmbH'
__license__ = 'MIT'
__description__ = 'Sycronise pytest results to Jira RMsis'
__keywords__ = 'py.test pytest rmsis jira'
__version__ = '1.0.0'
